import base64
import json
import itertools
import unittest
import time
import socket
import struct

import sh

import zdb

import zsearch_definitions.query
import zsearch_definitions.admin

from zsearch_definitions import common_pb2


class ZDBTestCase(unittest.TestCase):

    @staticmethod
    def deltaKeyMatchesRecord(d, r):
        if a.ip != r.ip:
            return False
        if d.domain != r.domain:
            return False
        return True

    @staticmethod
    def recordsMatch(a, b):
        if a.ip != b.ip:
            return False
        if a.domain != b.domain:
            return False
        if a.port != b.port:
            return False
        if a.protocol != b.protocol:
            return False
        if a.subprotocol != b.subprotocol:
            return False
        return True

    @classmethod
    def setUpClass(cls):
        cls.c = zdb.get_zdb_test_config()

    def setUp(self):
        pkill = sh.Command("pkill")
        try:
            pkill("-9", "zdb")
        except sh.ErrorReturnCode:
            pass
        sh.rm("-rf", sh.glob("/tmp/zdb/*"))
        self.zdb_handle = self.c.zdb(_bg=True, _err="zdb_stderr.txt")
        time.sleep(1)

        self.query_grpc = zsearch_definitions.query.QueryService()
        self.admin_grpc = zsearch_definitions.admin.AdminService()
        self._max_version = 0

    def tearDown(self):
        if self.zdb_handle is not None:
            self.zdb_handle.terminate()

    def assertTagsEqual(self, a, b):
        self.assertEqual(len(a), len(b))
        for atag, btag in itertools.izip(a, b):
            self.assertEqual(atag, btag)

    def assertMetadatumEqual(self, a, b):
        self.assertEqual(a.key, b.key)
        self.assertEqual(a.value, b.value)

    def assertMetadataEqual(self, a, b):
        self.assertEqual(len(a), len(b))
        for am, bm in itertools.izip(a, b):
            self.assertMetadatumEqual(am, bm)

    def assertProtocolAtomEqual(self, a, b):
        # Check data
        self.assertEqual(a.data, b.data)

        # Check tags
        if a.tags is None:
            self.assertIsNone(b.tags)
        else:
            self.assertIsNotNone(b.tags)
            self.assertTagsEqual(a.tags, b.tags)

        # Check metadata
        if a.metadata is None:
            self.assertIsNone(b.metadata)
        else:
            self.assertIsNotNone(b.metadata)
            self.assertMetadataEqual(a.metadata, b.metadata)

    def assertRecordEqual(self, a, b,
                          check_scan_id=True, check_timestamp=True,
                          check_first_seen_at=True, check_last_seen_at=True):
        self.assertEqual(a.ip, b.ip)
        self.assertEqual(a.port, b.port)
        self.assertEqual(a.protocol, b.protocol)
        self.assertEqual(a.subprotocol, b.subprotocol)
        self.assertEqual(a.domain, b.domain)
        self.assertEqual(a.scanid, b.scanid)
        if check_timestamp:
            self.assertEqual(a.timestamp, b.timestamp)
        if check_scan_id:
            self.assertEqual(a.scanid, b.scanid)
        self.assertEqual(a.sha256fp, b.sha256fp)
        if check_first_seen_at:
            self.assertEqual(a.first_seen_at_scan_id, b.first_seen_at_scan_id)
        if check_last_seen_at:
            self.assertEqual(a.last_seen_at_scan_id, b.last_seen_at_scan_id)
        self.assertEqual(a.HasField("atom"), b.HasField("atom"))
        if a.HasField("atom"):
            self.assertProtocolAtomEqual(a.atom, b.atom)
        else:
            # Not yet implemented
            self.fail()

    def assertDeltaMatchesRecords(self, delta, records):
        delta_records = delta.records
        self.assertTrue(delta.version > 0)
        atom_records = filter(lambda x: x.HasField("atom"), delta_records)
        self.assertEqual(len(atom_records), len(records))
        for record in records:
            self.assertEqual(delta.ip, record.ip)
            self.assertEqual(delta.domain, record.domain)
            found = [
                dr for dr in delta_records
                if ZDBTestCase.recordsMatch(dr, record)
            ]
            self.assertEqual(1, len(found))
            delta_record = found[0]
            self.assertRecordEqual(record, delta_record)
        max_delta_record_version = 0
        for record in delta.records:
            if record.version > max_delta_record_version:
                max_delta_record_version = record.version
        self.assertEqual(max_delta_record_version, delta.version)
        self.assertTrue(delta.version > 0)

    def assertDeltaContainsRecord(self, delta, record):
        delta_records = delta.records
        found = [
            dr for dr in delta_records
            if ZDBTestCase.recordsMatch(dr, record)
        ]
        self.assertEqual(1, len(found))
        self.assertRecordEqual(record, found[0])

    def assertDeltaMatchesHostQuery(self, delta, host_query):
        self.assertEqual(delta.ip, host_query.ip)
        self.assertEqual(delta.domain, host_query.domain)


    def assertAnonymousDeltaMatchesRecord(self, delta, record):
        # unimplemented
        self.fail()

    def assertAnoymousDeltaMatchesCertificate(self, delta, certificate):
        record = delta.record
        self.assertIsNotNone(record)
        self.assertAnonymousRecordMatchesCertificate(record, certificate)

    def assertHostQueryResponseMatchesHostQuery(self, res, query):
        self.assertEqual(query.ip, res.ip)
        self.assertEqual(query.port, res.port)
        self.assertEqual(query.protocol, res.protocol)
        self.assertEqual(query.subprotocol , res.subprotocol)
        self.assertEqual(query.domain, res.domain)

    def assertAnonymousRecordMatchesCertificate(self, record, certificate):
        raw = certificate["raw"]
        parsed = certificate["parsed"]
        self.assertIsNotNone(record)
        self.assertTrue(record.HasField("certificate"))
        rc = record.certificate
        self.assertIsNotNone(rc)
        self.assertEqual(raw, base64.b64encode(rc.raw))
        cert_json = json.dumps(parsed, sort_keys=True)
        self.assertEqual(cert_json, rc.parsed)
        sha1fp = parsed["fingerprint_sha1"].decode("hex")
        sha256fp = parsed["fingerprint_sha256"].decode("hex")
        self.assertEqual(sha1fp, rc.sha1fp)
        self.assertEqual(sha256fp, rc.sha256fp)
        self.assertEqual(sha256fp, record.sha256fp)


    def makeTwoSetOfRecordsWithDifferentTagsAndMetdata(
            self, start_ip, stop_ip,
            first_port, first_protocol, first_subprotocol,
            second_port, second_protocol, second_subprotocol):
        first_tags = ["a", "b"]
        second_tags = ["b", "c"]
        first_metadata = [
            common_pb2.Metadatum(key="k1", value="v1"),
            common_pb2.Metadatum(key="k2", value="v2"),
            common_pb2.Metadatum(key="k3", value="v1"),
        ]
        second_metadata = [
            common_pb2.Metadatum(key="k2", value="a"),
            common_pb2.Metadatum(key="k3", value="b"),
            common_pb2.Metadatum(key="k4", value="c"),
        ]
        first_atoms = zdb.iter_protocol_atom(
            tags_list=itertools.cycle([first_tags]),
            metadata_list=itertools.cycle([first_metadata]),
        )
        second_atoms = zdb.iter_protocol_atom(
            tags_list=itertools.cycle([second_tags]),
            metadata_list=itertools.cycle([second_metadata]),
        )
        first_records = list(zdb.iter_ipv4_record(
                start_ip, first_port, first_protocol, first_subprotocol,
                ip_stop=stop_ip, ip_step=1, atom_list=first_atoms,
        ))
        second_records = list(zdb.iter_ipv4_record(
                start_ip, second_port, second_protocol, second_subprotocol,
                ip_stop=stop_ip, ip_step=1, atom_list=second_atoms,
        ))
        return first_records, second_records

    def htons(self, short):
        short_bytes = struct.pack("!H", short)
        (network_short, ) = struct.unpack("H", short_bytes)
        return network_short



import json
import test.testcase
import time
import json
import os.path
import sys
import unittest

from zsearch_definitions.protocols_pb2 import Protocol, Subprotocol

class TestDomainDumpTestCase(test.testcase.ZDBTestCase):

    TEST_HTTPS_TLS = json.dumps({"tls_enabled":True, "tls_version":"TLSv1.2"}, sort_keys=True)
    TEST_HTTPS_HB = json.dumps({"heartbeat_enabled":True, "heartbleed_vulnerable":False}, sort_keys=True)
    TEST_FTP_BANNER = json.dumps({"banner":"go away drew springall"}, sort_keys=True)

    def add_mock_records(self):
        self.query_grpc.put_host_domain_record("google.com", "141.212.120.5", 443,
                "PROTO_HTTPS",
                "SUBPROTO_TLS",
                self.TEST_HTTPS_TLS,
                tags=["tag_https", "tag_https2"])
        self.query_grpc.put_host_domain_record("google.com", "141.212.120.5", 443,
                "PROTO_HTTPS",
                "SUBPROTO_HEARTBLEED",
                self.TEST_HTTPS_HB)
        self.query_grpc.put_host_domain_record("google.com", "141.212.108.1", 22,
                "PROTO_FTP",
                "SUBPROTO_BANNER",
                self.TEST_FTP_BANNER,
                metadata={"manufacturer":"Google!"})
        self.query_grpc.put_host_domain_record("facebook.com", "141.212.121.1", 22,
                "PROTO_FTP",
                "SUBPROTO_BANNER",
                self.TEST_FTP_BANNER,
                metadata={"manufacturer":"Dell"})

    def parse_domain_json_dump(self, path):
        retv = {}
        with open(path) as fd:
            for line in fd:
                j = json.loads(line.strip())
                retv[j["domain"]] = j
        return retv

    VALID = json.loads("""{"__restricted_location":{"city":"Ann Arbor","continent":"North America","country":"United States","country_code":"US","latitude":42.292299999999997,"longitude":-83.714500000000001,"postal_code":"48109","province":"Michigan","registered_country":"United States","registered_country_code":"US","timezone":"America/Detroit"},"ip":"141.212.121.1","ip_int":2379512065,"location":{"city":"Ann Arbor","continent":"North America","country":"United States","country_code":"US","latitude":42.292299999999997,"longitude":-83.714500000000001,"postal_code":"48109","province":"Michigan","registered_country":"United States","registered_country_code":"US","timezone":"America/Detroit"},"metadata":{"manufacturer":"Dell"},"p22":{"ftp":{"banner":{"banner":"go away drew springall"}}},"p443":{"https":{"heartbleed":{"heartbeat_enabled":true,"heartbleed_vulnerable":false},"tls":{"tls_enabled":true,"tls_version":"TLSv1.2"}}},"tags":["tag_https","tag_https2"]}""")

    def test_json_dumps(self):
        if os.path.exists("domain.json"):
            os.remove("domain.json")
        time.sleep(1)
        self.add_mock_records()
        record_count = 0
        for record in self.query_grpc.iter_domain_records():
            record_count += 1
        self.assertTrue(record_count > 0)
        self.admin_grpc.dump_domain(path="domain.json")
        #self.assertEqual(self.VALID, self.parse_domain_json_dump("domain.json")["google.com"])


if __name__ == "__main__":
    unittest.main()



import json
import test.testcase
import time
import json
import os.path
import sys

import unittest

from zsearch_definitions.protocols_pb2 import Protocol, Subprotocol

class TestIPv4DumpTestCase(test.testcase.ZDBTestCase):

    TEST_HTTPS_TLS = json.dumps({"tls_enabled":True, "tls_version":"TLSv1.2"})
    TEST_HTTPS_HB = json.dumps({"heartbeat_enabled":True, "heartbleed_vulnerable":False})
    TEST_FTP_BANNER = json.dumps({"banner":"go away drew springall"})

    def add_mock_records(self):
        self.query_grpc.put_host_ipv4_record("141.212.121.1", 443,
                "PROTO_HTTPS",
                "SUBPROTO_TLS",
                self.TEST_HTTPS_TLS,
                tags=["tag_https", "tag_https2"])
        self.query_grpc.put_host_ipv4_record("141.212.121.1", 443,
                "PROTO_HTTPS",
                "SUBPROTO_HEARTBLEED",
                self.TEST_HTTPS_HB)
        self.query_grpc.put_host_ipv4_record("141.212.121.1", 22,
                "PROTO_FTP",
                "SUBPROTO_BANNER",
                self.TEST_FTP_BANNER,
                metadata={"manufacturer":"Dell"})
#        self.query_grpc.put_host_ipv4_record("141.212.121.10", 22,
#                "PROTO_FTP",
#                "SUBPROTO_BANNER",
#                self.TEST_FTP_BANNER,
#                metadata={"manufacturer":"Dell 234"})


    def parse_ipv4_json_dump(self, path):
        retv = {}
        with open(path) as fd:
            for line in fd:
                j = json.loads(line.strip())
                retv[j["ip"]] = j
        return retv

    VALID = json.loads("""{"__restricted_location":{"city":"Ann Arbor","continent":"North America","country":"United States","country_code":"US","latitude":42.292299999999997,"longitude":-83.714500000000001,"postal_code":"48109","province":"Michigan","registered_country":"United States","registered_country_code":"US","timezone":"America/Detroit"},"ip":"141.212.121.1","ipint":2379512065,"location":{"city":"Ann Arbor","continent":"North America","country":"United States","country_code":"US","latitude":42.292299999999997,"longitude":-83.714500000000001,"postal_code":"48109","province":"Michigan","registered_country":"United States","registered_country_code":"US","timezone":"America/Detroit"},"metadata":{"manufacturer":"Dell"},"p22":{"ftp":{"banner":{"banner":"go away drew springall"}}},"p443":{"https":{"heartbleed":{"heartbeat_enabled":true,"heartbleed_vulnerable":false},"tls":{"tls_enabled":true,"tls_version":"TLSv1.2"}}},"tags":["tag_https","tag_https2"]}""")

    def test_json_dumps(self):
        if os.path.exists("ipv4.json"):
            os.remove("ipv4.json")
        time.sleep(1)
        self.add_mock_records()
        self.admin_grpc.dump_ipv4(path="ipv4.json")
        valid_dumped = json.dumps(self.VALID, sort_keys=True)
        dump = self.parse_ipv4_json_dump("ipv4.json")
        read_back_dumped = json.dumps(dump["141.212.121.1"], sort_keys=True)
        self.assertEqual(valid_dumped, read_back_dumped)

if __name__ == "__main__":
    unittest.main()



import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2
import time
import unittest

import testcase


class DomainTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    DOMAINS = ["davidadrian.org", "zakird.com", "umich.edu", "google.com"]

    def setUp(self):
        super(DomainTest, self).setUp()
        self.service = self.query_grpc.service

    def test_insert_host_same_tags_metdata(self):
        domain = "davidadrian.org"
        ip = 0x8dd47859
        records = list()
        first = True
        for port in range(1, 10):
            record = zdb.get_domain_record(domain, port, 20, 5)
            records.append(record)
            delta = self.service.PutHostDomainRecord(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, records)


    def test_insert_multiple_host(self):
        for domain in self.DOMAINS:
            record = zdb.get_domain_record(domain, 443, 5, 6)
            delta = self.service.PutHostDomainRecord(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [record])

    def test_scopes(self):
        domain = "davidadrian.org"
        first = zdb.get_domain_record(domain, 443, 5, 6)
        delta = self.service.PutHostDomainRecord(first, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first])
        second = zdb.get_domain_record(domain, 80, 5, 6)
        delta = self.service.PutHostDomainRecord(second, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first, second])
        third = zdb.get_domain_record(domain, 443, 10, 4)
        delta = self.service.PutHostDomainRecord(third, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first, second, third])
        fourth = zdb.get_domain_record(domain, 443, 10, 6)
        delta = self.service.PutHostDomainRecord(fourth, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first, second, third, fourth])
        fifth = zdb.get_domain_record(domain, 443, 12, 6)
        delta = self.service.PutHostDomainRecord(fifth, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first, second, third, fourth, fifth])
        sixth = zdb.get_domain_record("yolo.swag", 443, 12, 6)
        delta = self.service.PutHostDomainRecord(sixth, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [sixth])
        atom = zdb.get_protocol_atom(tags=["different", "think"])
        seventh = zdb.get_domain_record(domain, 443, 10, 4, atom=atom)
        delta = self.service.PutHostDomainRecord(seventh, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        self.assertDeltaMatchesRecords(delta, [first, second, fourth, fifth, seventh])
        eighth = zdb.get_domain_record(domain, 80, 5, 6)
        delta = self.service.PutHostDomainRecord(seventh, self.TIMEOUT)
        self.assertEqual(delta.delta_type, common_pb2.DT_NO_CHANGE)


if __name__ == "__main__":
    unittest.main()



import json
import test.testcase
import time
import unittest

from zsearch_definitions import anonstore_pb2


class CertificateTests(test.testcase.ZDBTestCase):

    TIMEOUT = 3

    def setUp(self):
        super(CertificateTests, self).setUp()
        self.service = self.query_grpc.service

    def get_mock_certificates(self):
        certs = json.loads(open("test/certificates.json").read())
        return certs

    def add_mock_certificates(self):
        certs = self.get_mock_certificates()
        for cert in certs:
            self.query_grpc.put_certificate(cert["raw"], cert["parsed"])
        return certs

    def test_add_new_certificates(self):
        certs = self.get_mock_certificates()
        for cert in certs:
            raw = cert["raw"]
            parsed = cert["parsed"]
            delta = self.query_grpc.put_certificate(raw, parsed)
            self.assertEqual(delta.delta_type, anonstore_pb2.AnonymousDelta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, anonstore_pb2.AnonymousDelta.SCOPE_NEW)
            self.assertAnoymousDeltaMatchesCertificate(delta, cert)

    def test_add_repeat_certificates(self):
        certs = self.add_mock_certificates()
        for cert in certs:
            raw = cert["raw"]
            parsed = cert["parsed"]
            delta = self.query_grpc.put_certificate(raw, parsed)
            self.assertEqual(delta.delta_type, anonstore_pb2.AnonymousDelta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, anonstore_pb2.AnonymousDelta.SCOPE_NO_CHANGE)

    def test_certificate_dump(self):
        certs = self.add_mock_certificates()
        original_raw = {c["raw"] for c in certs}
        original_parsed = {json.dumps(c["parsed"], sort_keys=True) for c in certs}
        self.admin_grpc.dump_certificates(path="certificates.json", incremental=False)
        new_raw = set()
        new_parsed = set()
        with open("certificates.json", "r") as fd:
            for line in fd:
                c = json.loads(line)
                raw = c["raw"]
                parsed = c["parsed"]
                new_raw.add(raw)
                new_parsed.add(json.dumps(parsed, sort_keys=True))
        self.assertEqual(original_raw, new_raw)
        self.assertEqual(original_parsed, new_parsed)



if __name__ == "__main__":
    unittest.main()



import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2
import time
import unittest

import testcase


class DeleteTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    def setUp(self):
        super(DeleteTest, self).setUp()
        self.service = self.query_grpc.service

    def test_insert_delete_one_ipv4(self):
        record = zdb.get_ipv4_record(0x01020304, 443, 80, 5)
        delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
        self.assertIsNotNone(delta)
        hq = zdb.host_query_from_record(record)
        delta = self.service.DelHostIPv4Record(hq, self.TIMEOUT)
        self.assertIsNotNone(delta)
        self.assertEqual(delta.delta_type, common_pb2.DT_DELETE)
        self.assertDeltaMatchesHostQuery(delta, hq)
        self.assertDeltaMatchesRecords(delta, [])

    def test_insert_delete_one_domain(self):
        domain = "davidadrian.org"
        ip = 0x8dd47859
        record = zdb.get_domain_record(domain, 80, 20, 5)
        delta = self.service.PutHostDomainRecord(record, self.TIMEOUT)
        self.assertIsNotNone(delta)
        self.assertDeltaMatchesRecords(delta, [record])
        self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        host_query = zdb.host_query_from_record(record)
        delta = self.service.DelHostDomainRecord(host_query, self.TIMEOUT)
        self.assertIsNotNone(delta)
        self.assertEqual(delta.delta_type, common_pb2.DT_DELETE)
        self.assertDeltaMatchesHostQuery(delta, host_query)
        self.assertDeltaMatchesRecords(delta, [])

    def test_insert_many_delete_many(self):
        domain = "a.com"
        records = list()
        for port in range(1,10):
            record = zdb.get_domain_record(domain, port, 20, 5)
            records.append(record)
            delta = self.service.PutHostDomainRecord(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecords(delta, records)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        for idx, record in enumerate(records):
            hq = zdb.host_query_from_record(record)
            delta = self.service.DelHostDomainRecord(hq, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_DELETE)
            self.assertDeltaMatchesRecords(delta, records[idx + 1:])


if __name__ == "__main__":
    unittest.main()



import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2
import time
import unittest
import socket

import testcase


class DeltaTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    def setUp(self):
        super(DeltaTest, self).setUp()
        self.service = self.query_grpc.service

    def test_new_hosts(self):
        start_ip = 0x01020304
        stop_ip = start_ip + 10
        records = list(zdb.iter_ipv4_record(
                start_ip, 443, 3, 2, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecords(delta, [record])


    def test_identical_hosts(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 100
        records = list(zdb.iter_ipv4_record(
                start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertTrue(delta.version > 0)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_NO_CHANGE)

    def test_metadata_tags_merge(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 100
        records = list(zdb.iter_ipv4_record(
                start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
        m = {
            "another_key": "another_value",
            "zed_key": "zed_value",
            "new_key": "new_value",
            "key": "not the original value",
        }
        metadata_list = itertools.cycle([m])
        atoms = zdb.iter_protocol_atom(metadata_list=metadata_list)
        more_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 8, 6, ip_stop=stop_ip
        ))
        for record, new_record in itertools.izip(records, more_records):
            delta = self.service.PutHostIPv4Record(new_record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecords(delta, [record, new_record])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)


    def test_overwrite_subprotocol(self):
        start_ip = 0x5601afb6
        stop_ip = start_ip + 10
        records = list(zdb.iter_ipv4_record(
            start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        original_atoms = [record.atom for record in records]
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [record])
        new_atoms = [hoststore_pb2.ProtocolAtom(
                data=atom.data,
                tags=["new_tag"],
                metadata=[common_pb2.Metadatum(
                        key="new_metdatum_key", value="value")
                ],
        ) for atom in original_atoms]
        new_records = list(zdb.iter_ipv4_record(
            start_ip, 80, 5, 4, ip_stop=stop_ip, atom_list=new_atoms,
        ))
        for record in new_records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [record])

    def test_metadata_tags_merge_protocol(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 5
        first_subproto = 3
        second_subproto = 4
        first_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 5, first_subproto, ip_stop=stop_ip
        ))
        first_atoms = [record.atom for record in first_records]
        for record in first_records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecords(delta, [record])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)

        new_atoms = [hoststore_pb2.ProtocolAtom(
                data=atom.data,
                tags=["another_tag"],
                metadata=[common_pb2.Metadatum(
                        key="key",
                        value="new_value")
                ],
        ) for atom in first_atoms]
        second_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 5, second_subproto, ip_stop=stop_ip
        ))
        for first, second in itertools.izip(first_records, second_records):
            delta = self.service.PutHostIPv4Record(second, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [first, second])

    def test_metadata_tags_merge_port(self):
        first_proto = 5
        second_proto = 6
        first_subproto = 4
        second_subproto = 12
        tags = ["a", "b"]
        metadata = [
            common_pb2.Metadatum(key="k1", value="v1"),
            common_pb2.Metadatum(key="k2", value="v2"),
        ]
        first_atoms = zdb.iter_protocol_atom(
            tags_list=itertools.cycle([tags]),
            metadata_list=itertools.cycle([metadata])
        )
        start_ip = 0x18af03d8
        stop_ip = start_ip + 10*5
        first_records = list(zdb.iter_ipv4_record(
                start_ip, 443, first_proto, first_subproto, ip_stop=stop_ip,
                ip_step=5, atom_list=first_atoms
        ))
        for record in first_records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
        second_tags = ["b", "c"]
        second_metadata = [
            common_pb2.Metadatum(key="k2", value="v3"),
            common_pb2.Metadatum(key="k3", value="v3"),
        ]
        second_atoms = zdb.iter_protocol_atom(
            tags_list=itertools.cycle([second_tags]),
            metadata_list=itertools.cycle([second_metadata])
        )
        second_records = list(zdb.iter_ipv4_record(
                start_ip, 443, second_proto, second_subproto, ip_stop=stop_ip,
                ip_step=5, atom_list=second_atoms
        ))
        for first, second in itertools.izip(first_records, second_records):
            delta = self.service.PutHostIPv4Record(second, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecords(delta, [first, second])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)

    def test_metadata_tags_merge_host(self):
        start_ip = 0x58530275
        stop_ip = start_ip + 10
        ra, rb = self.makeTwoSetOfRecordsWithDifferentTagsAndMetdata(
            start_ip, stop_ip, 80, 8, 5, 443, 10, 6
        )
        for record in ra:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [record])
        for first, second in itertools.izip(ra, rb):
            delta = self.service.PutHostIPv4Record(second, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            self.assertDeltaMatchesRecords(delta, [first, second])

    def test_metadata_tags_merge_many(self):
        start_ip = 0x38ae5890
        stop_ip = start_ip + 5
        ra, rb = self.makeTwoSetOfRecordsWithDifferentTagsAndMetdata(
            start_ip, stop_ip, 443, 20, 6, 443, 20, 6
        )
        rc, rd = self.makeTwoSetOfRecordsWithDifferentTagsAndMetdata(
            start_ip, stop_ip, 80, 10, 5, 995, 10, 4
        )
        for a, b, c, d in itertools.izip(ra, rb, rc, rd):
            delta = self.service.PutHostIPv4Record(a, self.TIMEOUT)
            self.assertDeltaMatchesRecords(delta, [a])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            delta = self.service.PutHostIPv4Record(b, self.TIMEOUT)
            self.assertDeltaMatchesRecords(delta, [b])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            delta = self.service.PutHostIPv4Record(c, self.TIMEOUT)
            self.assertDeltaMatchesRecords(delta, [b, c])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)
            delta = self.service.PutHostIPv4Record(d, self.TIMEOUT)
            self.assertDeltaMatchesRecords(delta, [b, c, d])
            self.assertEqual(delta.delta_type, common_pb2.DT_UPDATE)


if __name__ == "__main__":
    unittest.main()



import sys
import zsearch_definitions.protocols_pb2

class Abstractocol(object):
    def __init__(self, value, name, pretty_name):
        self.value, self.name, self.pretty_name = value, name, pretty_name
    
    @classmethod 
    def from_value(cls, value):
        return cls._by_value[value]
    
    @classmethod
    def from_name(cls, name):
        return cls._by_name[name]
        
    @classmethod
    def from_pretty_name(cls, name):
        return cls._by_pretty_name[name]
    
    def __hash__(self):
        return self.value.__hash__()

    def __cmp__(self, other):
        return self.value.__cmp__(other.value)


# can't share between classes, so create abstract class with all the methods
# and then maintain your own things in sep children classes

class Subprotocol(Abstractocol):
    _by_pretty_name = {}
    _by_name = {}
    _by_value = {}


class Protocol(Abstractocol):
    _by_pretty_name = {}
    _by_name = {}
    _by_value = {}


for _spid in zsearch_definitions.protocols_pb2.Subprotocol.values():
    enum_name = zsearch_definitions.protocols_pb2.Subprotocol.Name(_spid)
    simple_name = enum_name[len("SUBPROTO_"):]
    pretty_name = simple_name.lower()
    object_ = Subprotocol(_spid, enum_name, pretty_name)
    Subprotocol._by_name[enum_name] = object_
    Subprotocol._by_value[_spid] = object_
    Subprotocol._by_pretty_name[pretty_name] = object_
    setattr(Protocol, simple_name, object_)
    
for _pid in zsearch_definitions.protocols_pb2.Protocol.values():
    enum_name = zsearch_definitions.protocols_pb2.Protocol.Name(_pid)
    simple_name = enum_name[len("PROTO_"):]
    pretty_name = simple_name.lower()
    object_ = Protocol(_pid, enum_name, pretty_name)
    Protocol._by_name[enum_name] = object_
    Protocol._by_value[_pid] = object_
    Protocol._by_pretty_name[pretty_name] = object_
    setattr(sys.modules[__name__], simple_name, object_)




import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2, rpc_pb2, protocols_pb2
from zsearch_definitions.protocols_pb2 import Protocol, Subprotocol
import time
import unittest
import socket



import testcase


class PruneTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    MIN_HTTPS_TLS_SCAN_ID = 4
    MIN_HTTP_GET_SCAN_ID = 8

    MIN_SCAN_IDS = [
        (443, protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_TLS, MIN_HTTPS_TLS_SCAN_ID),
        (80, protocols_pb2.PROTO_HTTP, protocols_pb2.SUBPROTO_GET, MIN_HTTP_GET_SCAN_ID),
    ]

    IPV4_DELTA_QUEUE = "ipv4_deltas"
    DOMAIN_DELTA_QUEUE = "domain_deltas"

    def setUp(self):
        super(PruneTest, self).setUp()
        self.rctx = self.c.redis
        self.admin_service = self.admin_grpc.service
        self.query_service = self.query_grpc.service
        self.rctx.delete(self.IPV4_DELTA_QUEUE)
        self.rctx.delete(self.DOMAIN_DELTA_QUEUE)

    def make_prune_command(self, min_scan_ids):
        cmd = rpc_pb2.Command()
        for port, protocol, subprotocol, min_scan_id in min_scan_ids:
            network_port = self.htons(port)
            ak = hoststore_pb2.AnonymousKey(port=network_port, protocol=protocol,
                                            subprotocol=subprotocol)
            min_id = cmd.min_scan_ids.add()
            min_id.key.CopyFrom(ak)
            min_id.min_scan_id = min_scan_id
        return cmd

    def add_mock_ipv4(self):
        pass

    def test_prune_empty(self):
        cmd = self.make_prune_command(self.MIN_SCAN_IDS)
        res = self.admin_service.PruneIPv4(cmd, self.TIMEOUT)
        self.assertEqual(res.status, rpc_pb2.CommandReply.SUCCESS)

    def test_prune_one_protocol(self):
        records = list()
        for scan_id in range(0,10):
            ip = 0x010203 + scan_id
            record = zdb.get_ipv4_record(
                ip, 443,
                protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_TLS,
                scan_id=scan_id
            )
            records.append(record)
        for record in records:
            delta = self.query_service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertDeltaMatchesRecords(delta, [record])
        cmd = self.make_prune_command(self.MIN_SCAN_IDS)
        res = self.admin_service.PruneIPv4(cmd, self.TIMEOUT)
        self.assertEqual(res.status, rpc_pb2.CommandReply.SUCCESS)
        for record in records:
            hq = zdb.host_query_from_record(record)
            res = self.query_service.GetHostIPv4Record(hq, self.TIMEOUT)
            if record.scanid < self.MIN_HTTPS_TLS_SCAN_ID:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.NO_RECORD)
            else:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.SUCCESS)
                self.assertRecordEqual(record, res.record)

    def test_prune_many_protocols(self):
        https_records = list()
        http_records = list()
        other_records = list()
        scan_ids = reversed(range(1, 20, 3))
        start_ip = 0x8945ebc6
        ips = range(start_ip, start_ip + 10)
        for sid, ip in itertools.izip(scan_ids, ips):
            https_record = zdb.get_ipv4_record(
                ip, 443,
                protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_TLS,
                scan_id=sid,
            )
            http_record = zdb.get_ipv4_record(
                ip, 80,
                protocols_pb2.PROTO_HTTP, protocols_pb2.SUBPROTO_GET,
                scan_id=sid+1,
            )
            other = zdb.get_ipv4_record(
                ip, 443,
                protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_GET,
                scan_id=sid+2,
            )
            https_records.append(https_record)
            http_records.append(http_record)
            other_records.append(other)
        for record in itertools.chain(
                https_records, http_records, other_records):
            delta = self.query_service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertDeltaContainsRecord(delta, record)
        self.rctx.delete(self.IPV4_DELTA_QUEUE)
        cmd = self.make_prune_command(self.MIN_SCAN_IDS)
        res = self.admin_service.PruneIPv4(cmd, self.TIMEOUT)
        self.assertEqual(rpc_pb2.CommandReply.SUCCESS, res.status)
        pruned_records = list()
        for https in https_records:
            hq = zdb.host_query_from_record(https)
            res = self.query_service.GetHostIPv4Record(hq, self.TIMEOUT)
            if https.scanid < self.MIN_HTTPS_TLS_SCAN_ID:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.NO_RECORD)
                pruned_records.append(https)
            else:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.SUCCESS)
                self.assertRecordEqual(https, res.record)
        for http in http_records:
            hq = zdb.host_query_from_record(http)
            res = self.query_service.GetHostIPv4Record(hq, self.TIMEOUT)
            if http.scanid < self.MIN_HTTP_GET_SCAN_ID:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.NO_RECORD)
                pruned_records.append(http)
            else:
                self.assertEqual(res.status, rpc_pb2.HostQueryResponse.SUCCESS)
                self.assertRecordEqual(http, res.record)
        for other in other_records:
            hq = zdb.host_query_from_record(other)
            res = self.query_service.GetHostIPv4Record(hq, self.TIMEOUT)
            self.assertEqual(res.status, rpc_pb2.HostQueryResponse.SUCCESS)
            self.assertRecordEqual(other, res.record)
        expected_deltas = len(pruned_records)
        self.assertTrue(expected_deltas > 0)
        deltas = list()
        for idx in range(0, expected_deltas):
            raw_delta = self.rctx.blpop(self.IPV4_DELTA_QUEUE, timeout=3)
            self.assertIsNotNone(raw_delta)
            self.assertEqual(2, len(raw_delta))
            delta = hoststore_pb2.Delta()
            delta.ParseFromString(raw_delta[1])
            deltas.append(delta)
        delta_queue_len = self.rctx.llen(self.IPV4_DELTA_QUEUE)
        self.assertEqual(0, delta_queue_len)
        for delta in deltas:
            self.assertEqual(delta.delta_type, common_pb2.DT_DELETE)

    def test_prune_domain(self):
        domains = ["a.com", "b.com", "c.com", "google.com"]
        scan_ids = range(1,10)
        records = list()
        for domain, sid in itertools.izip(domains, scan_ids):
            record = zdb.get_domain_record(
                domain, 443,
                protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_TLS,
                scan_id=sid,
            )
            self.query_service.PutHostDomainRecord(record, self.TIMEOUT)
            records.append(record)
        self.rctx.delete(self.DOMAIN_DELTA_QUEUE)
        cmd = self.make_prune_command(self.MIN_SCAN_IDS)
        prune_result = self.admin_service.PruneDomain(cmd, self.TIMEOUT)
        self.assertEqual(rpc_pb2.CommandReply.SUCCESS, prune_result.status)
        pruned_records = list()
        for record in records:
            hq = zdb.host_query_from_record(record)
            res = self.query_service.GetHostDomainRecord(hq, self.TIMEOUT)
            if record.scanid < self.MIN_HTTPS_TLS_SCAN_ID:
                self.assertEqual(rpc_pb2.HostQueryResponse.NO_RECORD, res.status)
                pruned_records.append(record)
            else:
                self.assertEqual(rpc_pb2.CommandReply.SUCCESS, res.status)
                self.assertRecordEqual(record, res.record)
        delta_len = self.rctx.llen(self.DOMAIN_DELTA_QUEUE)
        self.assertEqual(len(pruned_records), delta_len)
        for record in pruned_records:
            raw_delta = self.rctx.blpop(self.DOMAIN_DELTA_QUEUE)
            self.assertEqual(2, len(raw_delta))
            delta = hoststore_pb2.Delta()
            delta.ParseFromString(raw_delta[1])
            self.assertEqual(delta.delta_type, common_pb2.DT_DELETE)

    def test_cannot_prune_version(self):
        min_ids = [
            (25, protocols_pb2.PROTO_HTTPS, protocols_pb2.SUBPROTO_SYS_VERSION, 20),
        ]
        cmd = self.make_prune_command(min_ids)
        res = self.admin_service.PruneIPv4(cmd, self.TIMEOUT)
        self.assertEqual(res.status, rpc_pb2.CommandReply.ERROR)
        res = self.admin_service.PruneDomain(cmd, self.TIMEOUT)
        self.assertEqual(res.status, rpc_pb2.CommandReply.ERROR)




if __name__ == "__main__":
    unittest.main()



import socket
import os.path
import sys

from zsearch_definitions import search_pb2
from zsearch_definitions import rpc_pb2
from zsearch_definitions import hoststore_pb2 
from zsearch_definitions.protocols import Protocol, Subprotocol

class AdminService(object):
    TIMEOUT = 60*60*4 # second
    HOST = "localhost"
    PORT = 8080

    VALID_DATASTORES = [
        "IPV4",
        "DOMAIN",
        "CERTIFICATE",
        "KEY"
    ]

    def __init__(self, host=None, port=None):
        host = host or self.HOST
        port = port or self.PORT
        self._service = search_pb2.early_adopter_create_AdminService_stub(host, port).__enter__()

    @property
    def service(self):
        return self._service

    def shutdown(self):
        return self._service.Shutdown(rpc_pb2.Command(), self.TIMEOUT)

    def status(self):
        return self._service.Status(rpc_pb2.Command(), self.TIMEOUT)

    def statistics(self, datastore):
        ds = rpc_pb2.Command.Datastore.Value(datastore)
        return self._service.Statistics(rpc_pb2.Command(datastore=ds), self.TIMEOUT)

    def update_ases(self, path):
        retv = self._service.UpdateASData(rpc_pb2.Command(filepath=path))
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv

    def dump_certificates(self, path, incremental=False, max_records=0):
        retv = self._service.DumpCertificatesToJSON(rpc_pb2.Command(filepath=path,
                incremental_dump=incremental, max_records=max_records), 4*60*60)
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv

    def dump_ipv4(self, path, max_records=0, min_scan_ids=None):
        if min_scan_ids:
            cmd = self._make_prune_cmd(min_scan_ids)
        else:
            cmd = rpc_pb2.Command()
        cmd.filepath = path
        cmd.max_records = max_records
        retv = self._service.DumpIPv4ToJSON(cmd, 8*60*60)
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv

    def dump_domain(self, path, max_records=0, min_scan_ids=None):
        if min_scan_ids:
            cmd = self._make_prune_cmd(min_scan_ids)
        else:
            cmd = rpc_pb2.Command()
        cmd.filepath = path
        cmd.max_records = max_records
        retv = self._service.DumpDomainToJSON(cmd, 60*60)
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv


    def _make_prune_cmd(self, min_scan_ids):
        cmd = rpc_pb2.Command()
        for (host_port, pretty_protocol, pretty_subprotocol), min_scan_id in \
                min_scan_ids.iteritems():
            network_port = socket.htons(host_port)
            protocol = Protocol.from_pretty_name(pretty_protocol)
            subprotocol = Protocol.from_pretty_name(pretty_subprotocol)
            ak = hoststore_pb2.AnonymousKey(
                port=network_port,
                protocol=protocol.value, subprotocol=subprotocol.value,
            )
            min_id_obj = cmd.min_scan_ids.add()
            min_id_obj.key.CopyFrom(ak)
            min_id_obj.min_scan_id = min_scan_id
        return cmd

    def prune_domain(self, min_scan_ids):
        cmd = self._make_prune_cmd(min_scan_ids)
        retv = self._service.PruneDomain(cmd, self.TIMEOUT)
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv

    def prune_ipv4(self, min_scan_ids):
        '''min_scan_ids is a dictionary of the tuple
        (host_order_port, pretty_protocol_name, pretty_subprotocol_name):min_id
        '''
        cmd = self._make_prune_cmd(min_scan_ids)
        retv = self._service.PruneIPv4(cmd, self.TIMEOUT)
        if retv.status != rpc_pb2.CommandReply.SUCCESS:
            raise Exception("ZDB failure: %s" % retv.error)
        return retv

    def __del__(self):
        if self._service:
            self._service.__exit__(None, None, None)





import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2, protocols_pb2
from zsearch_definitions.protocols_pb2 import Protocol, Subprotocol
from zsearch_definitions.rpc_pb2 import *
import time
import unittest
import socket


import testcase


class QueryTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    def setUp(self):
        super(QueryTest, self).setUp()
        self.service = self.query_grpc.service

    def test_get_exists(self):
        record = zdb.get_ipv4_record(0x01020304, 443, 80, 5)
        delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
        self.assertIsNotNone(delta)
        hq = zdb.host_query_from_record(record)
        res = self.service.GetHostIPv4Record(hq, self.TIMEOUT)
        self.assertEqual(HostQueryResponse.SUCCESS, res.status)
        self.assertHostQueryResponseMatchesHostQuery(res, hq)
        self.assertRecordEqual(record, res.record)

    def test_get_nonexistant(self):
        record = zdb.get_ipv4_record(0x01020304, 443, 80, 5)
        hq = zdb.host_query_from_record(record)
        res = self.service.GetHostIPv4Record(hq, self.TIMEOUT)
        self.assertEqual(HostQueryResponse.NO_RECORD, res.status)

    def test_get_deleted(self):
        record = zdb.get_ipv4_record(0x01020304, 443, 80, 5)
        hq = zdb.host_query_from_record(record)
        delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
        delta = self.service.DelHostIPv4Record(hq, self.TIMEOUT)
        res = self.service.GetHostIPv4Record(hq, self.TIMEOUT)
        self.assertEqual(HostQueryResponse.NO_RECORD, res.status)


if __name__ == "__main__":
    unittest.main()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2
from zsearch_definitions import anonstore_pb2 as zsearch__definitions_dot_anonstore__pb2
from zsearch_definitions import hoststore_pb2 as zsearch__definitions_dot_hoststore__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/rpc.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x1dzsearch_definitions/rpc.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\x1a#zsearch_definitions/anonstore.proto\x1a#zsearch_definitions/hoststore.proto\"D\n\tMinScanId\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.zsearch.AnonymousKey\x12\x13\n\x0bmin_scan_id\x18\x02 \x01(\r\"t\n\x07\x43ommand\x12\x18\n\x10incremental_dump\x18\x01 \x01(\x08\x12(\n\x0cmin_scan_ids\x18\x02 \x03(\x0b\x32\x12.zsearch.MinScanId\x12\x10\n\x08\x66ilepath\x18\x03 \x01(\t\x12\x13\n\x0bmax_records\x18\x04 \x01(\r\"\x9d\x02\n\x18\x41nonymousStoreStatistics\x12\x15\n\rtotal_records\x18\x01 \x01(\x04\x12 \n\x18records_added_last_reset\x18\x02 \x01(\x04\x12\"\n\x1arecords_updated_last_reset\x18\x03 \x01(\x04\x12$\n\x1crecords_unchanged_last_reset\x18\x04 \x01(\x04\x12\x18\n\x10records_received\x18\x05 \x01(\x04\x12\x1e\n\x16records_in_redis_queue\x18\x06 \x01(\r\x12\x18\n\x10redis_queue_name\x18\x07 \x01(\t\x12\x12\n\nqueue_type\x18\x08 \x01(\t\x12\x16\n\x0eworker_threads\x18\t \x01(\r\"|\n\x0eStatisticsPair\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08protocol\x18\x02 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x03 \x01(\r\x12\x35\n\nstatistics\x18\x04 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics\"p\n\x0fStoreStatistics\x12\x31\n\x06global\x18\x01 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics\x12*\n\tprotocols\x18\x02 \x03(\x0b\x32\x17.zsearch.StatisticsPair\"\xef\x02\n\x10ServerStatistics\x12H\n\x10store_statistics\x18\x01 \x03(\x0b\x32..zsearch.ServerStatistics.StoreStatisticsEntry\x12[\n\x1a\x61nonymous_store_statistics\x18\x02 \x03(\x0b\x32\x37.zsearch.ServerStatistics.AnonymousStoreStatisticsEntry\x1aP\n\x14StoreStatisticsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.zsearch.StoreStatistics:\x02\x38\x01\x1a\x62\n\x1d\x41nonymousStoreStatisticsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics:\x02\x38\x01\"M\n\x0fPruneStatistics\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.zsearch.AnonymousKey\x12\x16\n\x0erecords_pruned\x18\x02 \x01(\x04\"\xe4\x01\n\x0c\x43ommandReply\x12\x33\n\x06status\x18\x01 \x01(\x0e\x32#.zsearch.CommandReply.CommandStatus\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12(\n\x05stats\x18\x03 \x01(\x0b\x32\x19.zsearch.ServerStatistics\x12\x32\n\x10prune_statistics\x18\x04 \x03(\x0b\x32\x18.zsearch.PruneStatistics\"2\n\rCommandStatus\x12\t\n\x05\x46\x41TAL\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"q\n\tHostQuery\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08protocol\x18\x04 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x05 \x01(\r\x12\x13\n\x0bmax_records\x18\x06 \x01(\r\"\xb8\x02\n\x11HostQueryResponse\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).zsearch.HostQueryResponse.ResponseStatus\x12\n\n\x02ip\x18\x02 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r\x12\x10\n\x08protocol\x18\x05 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x06 \x01(\r\x12\x1f\n\x06record\x18\x07 \x01(\x0b\x32\x0f.zsearch.Record\x12 \n\x07records\x18\x08 \x03(\x0b\x32\x0f.zsearch.Record\x12\r\n\x05\x65rror\x18\t \x01(\t\"E\n\x0eResponseStatus\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNO_RECORD\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"\"\n\x0e\x41nonymousQuery\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\"\x95\x02\n\x16\x41nonymousQueryResponse\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12>\n\x06status\x18\x02 \x01(\x0e\x32..zsearch.AnonymousQueryResponse.ResponseStatus\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\x12)\n\x07records\x18\x04 \x03(\x0b\x32\x18.zsearch.AnonymousRecord\x12\r\n\x05\x65rror\x18; \x01(\t\"E\n\x0eResponseStatus\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNO_RECORD\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"R\n\x0fUserDataRequest\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12#\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x15.zsearch.UserdataAtom\"\x9e\x01\n\x0eRootStoreQuery\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.zsearch.RootStoreQuery.RootStoreQueryType\"R\n\x12RootStoreQueryType\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07MOZILLA\x10\x01\x12\r\n\tMICROSOFT\x10\x02\x12\t\n\x05\x41PPLE\x10\x03\x12\x07\n\x03\x41LL\x10\x04\"<\n\x0eRootStoreReply\x12*\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x14.zsearch.Certificateb\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,zsearch__definitions_dot_anonstore__pb2.DESCRIPTOR,zsearch__definitions_dot_hoststore__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_COMMANDREPLY_COMMANDSTATUS = _descriptor.EnumDescriptor(
  name='CommandStatus',
  full_name='zsearch.CommandReply.CommandStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1494,
  serialized_end=1544,
)
_sym_db.RegisterEnumDescriptor(_COMMANDREPLY_COMMANDSTATUS)

_HOSTQUERYRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='zsearch.HostQueryResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RECORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1905,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_HOSTQUERYRESPONSE_RESPONSESTATUS)

_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='zsearch.AnonymousQueryResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RECORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1905,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS)

_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE = _descriptor.EnumDescriptor(
  name='RootStoreQueryType',
  full_name='zsearch.RootStoreQuery.RootStoreQueryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOZILLA', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MICROSOFT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2453,
  serialized_end=2535,
)
_sym_db.RegisterEnumDescriptor(_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE)


_MINSCANID = _descriptor.Descriptor(
  name='MinScanId',
  full_name='zsearch.MinScanId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.MinScanId.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_scan_id', full_name='zsearch.MinScanId.min_scan_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=218,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='zsearch.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='incremental_dump', full_name='zsearch.Command.incremental_dump', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_scan_ids', full_name='zsearch.Command.min_scan_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filepath', full_name='zsearch.Command.filepath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_records', full_name='zsearch.Command.max_records', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=336,
)


_ANONYMOUSSTORESTATISTICS = _descriptor.Descriptor(
  name='AnonymousStoreStatistics',
  full_name='zsearch.AnonymousStoreStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_records', full_name='zsearch.AnonymousStoreStatistics.total_records', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_added_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_added_last_reset', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_updated_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_updated_last_reset', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_unchanged_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_unchanged_last_reset', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_received', full_name='zsearch.AnonymousStoreStatistics.records_received', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_in_redis_queue', full_name='zsearch.AnonymousStoreStatistics.records_in_redis_queue', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='redis_queue_name', full_name='zsearch.AnonymousStoreStatistics.redis_queue_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue_type', full_name='zsearch.AnonymousStoreStatistics.queue_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='worker_threads', full_name='zsearch.AnonymousStoreStatistics.worker_threads', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=624,
)


_STATISTICSPAIR = _descriptor.Descriptor(
  name='StatisticsPair',
  full_name='zsearch.StatisticsPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.StatisticsPair.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.StatisticsPair.protocol', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.StatisticsPair.subprotocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='zsearch.StatisticsPair.statistics', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=750,
)


_STORESTATISTICS = _descriptor.Descriptor(
  name='StoreStatistics',
  full_name='zsearch.StoreStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='global', full_name='zsearch.StoreStatistics.global', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocols', full_name='zsearch.StoreStatistics.protocols', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=864,
)


_SERVERSTATISTICS_STORESTATISTICSENTRY = _descriptor.Descriptor(
  name='StoreStatisticsEntry',
  full_name='zsearch.ServerStatistics.StoreStatisticsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.ServerStatistics.StoreStatisticsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='zsearch.ServerStatistics.StoreStatisticsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1134,
)

_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY = _descriptor.Descriptor(
  name='AnonymousStoreStatisticsEntry',
  full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1234,
)

_SERVERSTATISTICS = _descriptor.Descriptor(
  name='ServerStatistics',
  full_name='zsearch.ServerStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_statistics', full_name='zsearch.ServerStatistics.store_statistics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anonymous_store_statistics', full_name='zsearch.ServerStatistics.anonymous_store_statistics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SERVERSTATISTICS_STORESTATISTICSENTRY, _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=1234,
)


_PRUNESTATISTICS = _descriptor.Descriptor(
  name='PruneStatistics',
  full_name='zsearch.PruneStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.PruneStatistics.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_pruned', full_name='zsearch.PruneStatistics.records_pruned', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1313,
)


_COMMANDREPLY = _descriptor.Descriptor(
  name='CommandReply',
  full_name='zsearch.CommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.CommandReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.CommandReply.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='zsearch.CommandReply.stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prune_statistics', full_name='zsearch.CommandReply.prune_statistics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDREPLY_COMMANDSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1544,
)


_HOSTQUERY = _descriptor.Descriptor(
  name='HostQuery',
  full_name='zsearch.HostQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.HostQuery.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.HostQuery.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.HostQuery.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.HostQuery.protocol', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.HostQuery.subprotocol', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_records', full_name='zsearch.HostQuery.max_records', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1659,
)


_HOSTQUERYRESPONSE = _descriptor.Descriptor(
  name='HostQueryResponse',
  full_name='zsearch.HostQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.HostQueryResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.HostQueryResponse.ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.HostQueryResponse.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.HostQueryResponse.port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.HostQueryResponse.protocol', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.HostQueryResponse.subprotocol', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.HostQueryResponse.record', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='zsearch.HostQueryResponse.records', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.HostQueryResponse.error', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HOSTQUERYRESPONSE_RESPONSESTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1974,
)


_ANONYMOUSQUERY = _descriptor.Descriptor(
  name='AnonymousQuery',
  full_name='zsearch.AnonymousQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousQuery.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2010,
)


_ANONYMOUSQUERYRESPONSE = _descriptor.Descriptor(
  name='AnonymousQueryResponse',
  full_name='zsearch.AnonymousQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousQueryResponse.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.AnonymousQueryResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousQueryResponse.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='zsearch.AnonymousQueryResponse.records', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.AnonymousQueryResponse.error', index=4,
      number=59, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSQUERYRESPONSE_RESPONSESTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2013,
  serialized_end=2290,
)


_USERDATAREQUEST = _descriptor.Descriptor(
  name='UserDataRequest',
  full_name='zsearch.UserDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.UserDataRequest.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.UserDataRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.UserDataRequest.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2292,
  serialized_end=2374,
)


_ROOTSTOREQUERY = _descriptor.Descriptor(
  name='RootStoreQuery',
  full_name='zsearch.RootStoreQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.RootStoreQuery.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROOTSTOREQUERY_ROOTSTOREQUERYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2377,
  serialized_end=2535,
)


_ROOTSTOREREPLY = _descriptor.Descriptor(
  name='RootStoreReply',
  full_name='zsearch.RootStoreReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='zsearch.RootStoreReply.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2537,
  serialized_end=2597,
)

_MINSCANID.fields_by_name['key'].message_type = zsearch__definitions_dot_hoststore__pb2._ANONYMOUSKEY
_COMMAND.fields_by_name['min_scan_ids'].message_type = _MINSCANID
_STATISTICSPAIR.fields_by_name['statistics'].message_type = _ANONYMOUSSTORESTATISTICS
_STORESTATISTICS.fields_by_name['global'].message_type = _ANONYMOUSSTORESTATISTICS
_STORESTATISTICS.fields_by_name['protocols'].message_type = _STATISTICSPAIR
_SERVERSTATISTICS_STORESTATISTICSENTRY.fields_by_name['value'].message_type = _STORESTATISTICS
_SERVERSTATISTICS_STORESTATISTICSENTRY.containing_type = _SERVERSTATISTICS
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.fields_by_name['value'].message_type = _ANONYMOUSSTORESTATISTICS
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.containing_type = _SERVERSTATISTICS
_SERVERSTATISTICS.fields_by_name['store_statistics'].message_type = _SERVERSTATISTICS_STORESTATISTICSENTRY
_SERVERSTATISTICS.fields_by_name['anonymous_store_statistics'].message_type = _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY
_PRUNESTATISTICS.fields_by_name['key'].message_type = zsearch__definitions_dot_hoststore__pb2._ANONYMOUSKEY
_COMMANDREPLY.fields_by_name['status'].enum_type = _COMMANDREPLY_COMMANDSTATUS
_COMMANDREPLY.fields_by_name['stats'].message_type = _SERVERSTATISTICS
_COMMANDREPLY.fields_by_name['prune_statistics'].message_type = _PRUNESTATISTICS
_COMMANDREPLY_COMMANDSTATUS.containing_type = _COMMANDREPLY
_HOSTQUERYRESPONSE.fields_by_name['status'].enum_type = _HOSTQUERYRESPONSE_RESPONSESTATUS
_HOSTQUERYRESPONSE.fields_by_name['record'].message_type = zsearch__definitions_dot_hoststore__pb2._RECORD
_HOSTQUERYRESPONSE.fields_by_name['records'].message_type = zsearch__definitions_dot_hoststore__pb2._RECORD
_HOSTQUERYRESPONSE_RESPONSESTATUS.containing_type = _HOSTQUERYRESPONSE
_ANONYMOUSQUERYRESPONSE.fields_by_name['status'].enum_type = _ANONYMOUSQUERYRESPONSE_RESPONSESTATUS
_ANONYMOUSQUERYRESPONSE.fields_by_name['record'].message_type = zsearch__definitions_dot_anonstore__pb2._ANONYMOUSRECORD
_ANONYMOUSQUERYRESPONSE.fields_by_name['records'].message_type = zsearch__definitions_dot_anonstore__pb2._ANONYMOUSRECORD
_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS.containing_type = _ANONYMOUSQUERYRESPONSE
_USERDATAREQUEST.fields_by_name['data'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_ROOTSTOREQUERY.fields_by_name['type'].enum_type = _ROOTSTOREQUERY_ROOTSTOREQUERYTYPE
_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE.containing_type = _ROOTSTOREQUERY
_ROOTSTOREREPLY.fields_by_name['certificates'].message_type = zsearch__definitions_dot_anonstore__pb2._CERTIFICATE
DESCRIPTOR.message_types_by_name['MinScanId'] = _MINSCANID
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['AnonymousStoreStatistics'] = _ANONYMOUSSTORESTATISTICS
DESCRIPTOR.message_types_by_name['StatisticsPair'] = _STATISTICSPAIR
DESCRIPTOR.message_types_by_name['StoreStatistics'] = _STORESTATISTICS
DESCRIPTOR.message_types_by_name['ServerStatistics'] = _SERVERSTATISTICS
DESCRIPTOR.message_types_by_name['PruneStatistics'] = _PRUNESTATISTICS
DESCRIPTOR.message_types_by_name['CommandReply'] = _COMMANDREPLY
DESCRIPTOR.message_types_by_name['HostQuery'] = _HOSTQUERY
DESCRIPTOR.message_types_by_name['HostQueryResponse'] = _HOSTQUERYRESPONSE
DESCRIPTOR.message_types_by_name['AnonymousQuery'] = _ANONYMOUSQUERY
DESCRIPTOR.message_types_by_name['AnonymousQueryResponse'] = _ANONYMOUSQUERYRESPONSE
DESCRIPTOR.message_types_by_name['UserDataRequest'] = _USERDATAREQUEST
DESCRIPTOR.message_types_by_name['RootStoreQuery'] = _ROOTSTOREQUERY
DESCRIPTOR.message_types_by_name['RootStoreReply'] = _ROOTSTOREREPLY

MinScanId = _reflection.GeneratedProtocolMessageType('MinScanId', (_message.Message,), dict(
  DESCRIPTOR = _MINSCANID,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.MinScanId)
  ))
_sym_db.RegisterMessage(MinScanId)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Command)
  ))
_sym_db.RegisterMessage(Command)

AnonymousStoreStatistics = _reflection.GeneratedProtocolMessageType('AnonymousStoreStatistics', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSSTORESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousStoreStatistics)
  ))
_sym_db.RegisterMessage(AnonymousStoreStatistics)

StatisticsPair = _reflection.GeneratedProtocolMessageType('StatisticsPair', (_message.Message,), dict(
  DESCRIPTOR = _STATISTICSPAIR,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.StatisticsPair)
  ))
_sym_db.RegisterMessage(StatisticsPair)

StoreStatistics = _reflection.GeneratedProtocolMessageType('StoreStatistics', (_message.Message,), dict(
  DESCRIPTOR = _STORESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.StoreStatistics)
  ))
_sym_db.RegisterMessage(StoreStatistics)

ServerStatistics = _reflection.GeneratedProtocolMessageType('ServerStatistics', (_message.Message,), dict(

  StoreStatisticsEntry = _reflection.GeneratedProtocolMessageType('StoreStatisticsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SERVERSTATISTICS_STORESTATISTICSENTRY,
    __module__ = 'zsearch_definitions.rpc_pb2'
    # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics.StoreStatisticsEntry)
    ))
  ,

  AnonymousStoreStatisticsEntry = _reflection.GeneratedProtocolMessageType('AnonymousStoreStatisticsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY,
    __module__ = 'zsearch_definitions.rpc_pb2'
    # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics.AnonymousStoreStatisticsEntry)
    ))
  ,
  DESCRIPTOR = _SERVERSTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics)
  ))
_sym_db.RegisterMessage(ServerStatistics)
_sym_db.RegisterMessage(ServerStatistics.StoreStatisticsEntry)
_sym_db.RegisterMessage(ServerStatistics.AnonymousStoreStatisticsEntry)

PruneStatistics = _reflection.GeneratedProtocolMessageType('PruneStatistics', (_message.Message,), dict(
  DESCRIPTOR = _PRUNESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.PruneStatistics)
  ))
_sym_db.RegisterMessage(PruneStatistics)

CommandReply = _reflection.GeneratedProtocolMessageType('CommandReply', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CommandReply)
  ))
_sym_db.RegisterMessage(CommandReply)

HostQuery = _reflection.GeneratedProtocolMessageType('HostQuery', (_message.Message,), dict(
  DESCRIPTOR = _HOSTQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.HostQuery)
  ))
_sym_db.RegisterMessage(HostQuery)

HostQueryResponse = _reflection.GeneratedProtocolMessageType('HostQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _HOSTQUERYRESPONSE,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.HostQueryResponse)
  ))
_sym_db.RegisterMessage(HostQueryResponse)

AnonymousQuery = _reflection.GeneratedProtocolMessageType('AnonymousQuery', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousQuery)
  ))
_sym_db.RegisterMessage(AnonymousQuery)

AnonymousQueryResponse = _reflection.GeneratedProtocolMessageType('AnonymousQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSQUERYRESPONSE,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousQueryResponse)
  ))
_sym_db.RegisterMessage(AnonymousQueryResponse)

UserDataRequest = _reflection.GeneratedProtocolMessageType('UserDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _USERDATAREQUEST,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.UserDataRequest)
  ))
_sym_db.RegisterMessage(UserDataRequest)

RootStoreQuery = _reflection.GeneratedProtocolMessageType('RootStoreQuery', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTOREQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreQuery)
  ))
_sym_db.RegisterMessage(RootStoreQuery)

RootStoreReply = _reflection.GeneratedProtocolMessageType('RootStoreReply', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTOREREPLY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreReply)
  ))
_sym_db.RegisterMessage(RootStoreReply)


_SERVERSTATISTICS_STORESTATISTICSENTRY.has_options = True
_SERVERSTATISTICS_STORESTATISTICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.has_options = True
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/hoststore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/hoststore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n#zsearch_definitions/hoststore.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\"\x0b\n\tWHOISAtom\"\xf1\x01\n\x0cLocationAtom\x12\x11\n\tcontinent\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x13\n\x0bpostal_code\x18\x05 \x01(\t\x12\x10\n\x08timezone\x18\x06 \x01(\t\x12\x10\n\x08province\x18\x07 \x01(\t\x12\x10\n\x08latitude\x18\x08 \x01(\x01\x12\x11\n\tlongitude\x18\t \x01(\x01\x12\x1a\n\x12registered_country\x18\n \x01(\t\x12\x1f\n\x17registered_country_code\x18\x0b \x01(\t\"P\n\x0cProtocolAtom\x12$\n\x08metadata\x18\x01 \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x02 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"C\n\x0c\x41nonymousKey\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08protocol\x18\x02 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x03 \x01(\r\"\x80\x04\n\x06Record\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x10\n\x08protocol\x18\x03 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x04 \x01(\r\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x07\x12\x0e\n\x06scanid\x18\x07 \x01(\r\x12\x10\n\x08sha256fp\x18\x08 \x01(\x0c\x12\x1d\n\x15\x66irst_seen_at_scan_id\x18\t \x01(\r\x12\x1c\n\x14last_seen_at_scan_id\x18\n \x01(\r\x12%\n\x04\x61tom\x18\x0b \x01(\x0b\x32\x15.zsearch.ProtocolAtomH\x00\x12\x31\n\x10private_location\x18\x0c \x01(\x0b\x32\x15.zsearch.LocationAtomH\x00\x12\"\n\x07\x61s_atom\x18\r \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12#\n\x05whois\x18\x0e \x01(\x0b\x32\x12.zsearch.WHOISAtomH\x00\x12)\n\x08userdata\x18\x0f \x01(\x0b\x32\x15.zsearch.UserdataAtomH\x00\x12\x14\n\nalexa_rank\x18\x10 \x01(\rH\x00\x12\x30\n\x0fpublic_location\x18\x11 \x01(\x0b\x32\x15.zsearch.LocationAtomH\x00\x12\x0f\n\x07version\x18\x12 \x01(\x04\x42\x0c\n\ndata_oneof\"~\n\x05\x44\x65lta\x12&\n\ndelta_type\x18\x01 \x01(\x0e\x32\x12.zsearch.DeltaType\x12\n\n\x02ip\x18\x02 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x04\x12 \n\x07records\x18\x05 \x03(\x0b\x32\x0f.zsearch.Recordb\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_WHOISATOM = _descriptor.Descriptor(
  name='WHOISAtom',
  full_name='zsearch.WHOISAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=93,
)


_LOCATIONATOM = _descriptor.Descriptor(
  name='LocationAtom',
  full_name='zsearch.LocationAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='continent', full_name='zsearch.LocationAtom.continent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='zsearch.LocationAtom.country', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='zsearch.LocationAtom.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='city', full_name='zsearch.LocationAtom.city', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='zsearch.LocationAtom.postal_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='zsearch.LocationAtom.timezone', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='province', full_name='zsearch.LocationAtom.province', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='zsearch.LocationAtom.latitude', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='zsearch.LocationAtom.longitude', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_country', full_name='zsearch.LocationAtom.registered_country', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_country_code', full_name='zsearch.LocationAtom.registered_country_code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=337,
)


_PROTOCOLATOM = _descriptor.Descriptor(
  name='ProtocolAtom',
  full_name='zsearch.ProtocolAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.ProtocolAtom.metadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.ProtocolAtom.tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.ProtocolAtom.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=419,
)


_ANONYMOUSKEY = _descriptor.Descriptor(
  name='AnonymousKey',
  full_name='zsearch.AnonymousKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.AnonymousKey.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.AnonymousKey.protocol', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.AnonymousKey.subprotocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=488,
)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='zsearch.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.Record.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.Record.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.Record.protocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.Record.subprotocol', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.Record.domain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.Record.timestamp', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scanid', full_name='zsearch.Record.scanid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Record.sha256fp', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_seen_at_scan_id', full_name='zsearch.Record.first_seen_at_scan_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_at_scan_id', full_name='zsearch.Record.last_seen_at_scan_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='atom', full_name='zsearch.Record.atom', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_location', full_name='zsearch.Record.private_location', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as_atom', full_name='zsearch.Record.as_atom', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whois', full_name='zsearch.Record.whois', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.Record.userdata', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alexa_rank', full_name='zsearch.Record.alexa_rank', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_location', full_name='zsearch.Record.public_location', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='zsearch.Record.version', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data_oneof', full_name='zsearch.Record.data_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=491,
  serialized_end=1003,
)


_DELTA = _descriptor.Descriptor(
  name='Delta',
  full_name='zsearch.Delta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.Delta.delta_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.Delta.ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.Delta.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='zsearch.Delta.version', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='zsearch.Delta.records', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1131,
)

_PROTOCOLATOM.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_RECORD.fields_by_name['atom'].message_type = _PROTOCOLATOM
_RECORD.fields_by_name['private_location'].message_type = _LOCATIONATOM
_RECORD.fields_by_name['as_atom'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_RECORD.fields_by_name['whois'].message_type = _WHOISATOM
_RECORD.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_RECORD.fields_by_name['public_location'].message_type = _LOCATIONATOM
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['atom'])
_RECORD.fields_by_name['atom'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['private_location'])
_RECORD.fields_by_name['private_location'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['as_atom'])
_RECORD.fields_by_name['as_atom'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['whois'])
_RECORD.fields_by_name['whois'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['userdata'])
_RECORD.fields_by_name['userdata'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['alexa_rank'])
_RECORD.fields_by_name['alexa_rank'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['public_location'])
_RECORD.fields_by_name['public_location'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_DELTA.fields_by_name['delta_type'].enum_type = zsearch__definitions_dot_common__pb2._DELTATYPE
_DELTA.fields_by_name['records'].message_type = _RECORD
DESCRIPTOR.message_types_by_name['WHOISAtom'] = _WHOISATOM
DESCRIPTOR.message_types_by_name['LocationAtom'] = _LOCATIONATOM
DESCRIPTOR.message_types_by_name['ProtocolAtom'] = _PROTOCOLATOM
DESCRIPTOR.message_types_by_name['AnonymousKey'] = _ANONYMOUSKEY
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['Delta'] = _DELTA

WHOISAtom = _reflection.GeneratedProtocolMessageType('WHOISAtom', (_message.Message,), dict(
  DESCRIPTOR = _WHOISATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.WHOISAtom)
  ))
_sym_db.RegisterMessage(WHOISAtom)

LocationAtom = _reflection.GeneratedProtocolMessageType('LocationAtom', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.LocationAtom)
  ))
_sym_db.RegisterMessage(LocationAtom)

ProtocolAtom = _reflection.GeneratedProtocolMessageType('ProtocolAtom', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCOLATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ProtocolAtom)
  ))
_sym_db.RegisterMessage(ProtocolAtom)

AnonymousKey = _reflection.GeneratedProtocolMessageType('AnonymousKey', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSKEY,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousKey)
  ))
_sym_db.RegisterMessage(AnonymousKey)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), dict(
  DESCRIPTOR = _RECORD,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Record)
  ))
_sym_db.RegisterMessage(Record)

Delta = _reflection.GeneratedProtocolMessageType('Delta', (_message.Message,), dict(
  DESCRIPTOR = _DELTA,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Delta)
  ))
_sym_db.RegisterMessage(Delta)


import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)
